package core.services;

import core.api.models.timemanager.taskSchedule.BasicScheduleFieldInfo;
import core.api.models.timemanager.taskSchedule.ScheduleFieldInfo;
import core.entities.User;
import core.entities.timemanager.AbstractSchedule;
import core.entities.timemanager.BasicTaskSchedule;
import core.entities.timemanager.Task;
import core.repositories.UserRepository;
import core.repositories.timemanager.ScheduleRepository;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.time.LocalDate;
import java.util.List;
import java.util.Optional;

@Service
public class TaskScheduleService {

    @Autowired private ScheduleRepository scheduleRepository;
    @Autowired private UserRepository userRepository;

    public List<AbstractSchedule> getAllSchedulesOfUser(String username) {
        return scheduleRepository.findAllByUsername(username);
    }

    public ServiceResult<AbstractSchedule> scheduleBasic(Task task, BasicScheduleFieldInfo scheduleFieldInfo) {
        if(task.isFinished() || scheduleFieldInfo.getScheduleDate().isBefore(LocalDate.now())) {
            return new ServiceResult<>(ServiceExitCode.INVALID_OPERATION);
        }

        BasicTaskSchedule basicTaskSchedule = new BasicTaskSchedule(task, scheduleFieldInfo.getScheduleDate());
        scheduleRepository.save(basicTaskSchedule);

        return new ServiceResult<>(basicTaskSchedule);
    }
}
